@@ -5,23 +5,24 @@
 # OUTPUT limma-design.tsv: limma-design.tsv 
 # OUTPUT foldchange.tsv: foldchange.tsv 
 # OUTPUT pvalues.tsv: pvalues.tsv 
-# PARAMETER main.effect1: main.effect1 TYPE METACOLUMN_SEL DEFAULT group (Main effect 1)
-# PARAMETER main.effect2: main.effect2 TYPE METACOLUMN_SEL DEFAULT EMPTY (Main effect 2)
-# PARAMETER main.effect3: main.effect3 TYPE METACOLUMN_SEL DEFAULT EMPTY (Main effect 3)
-# PARAMETER technical.replication: technical.replication TYPE METACOLUMN_SEL DEFAULT EMPTY (Technical replication)
-# PARAMETER pairing: pairing TYPE METACOLUMN_SEL DEFAULT EMPTY (Paired samples)
-# PARAMETER treat.main.effect1.as.factor: treat.main.effect1.as.factor TYPE [no: no, yes: yes] DEFAULT no (Should main.effect1 be treated as a factor)
-# PARAMETER treat.main.effect2.as.factor: treat.main.effect2.as.factor TYPE [no: no, yes: yes] DEFAULT no (Should main.effect2 be treated as a factor)
-# PARAMETER treat.main.effect3.as.factor: treat.main.effect3.as.factor TYPE [no: no, yes: yes] DEFAULT no (Should main.effect3 be treated as a factor)
-# PARAMETER adjust.p.values: adjust.p.values TYPE [yes: yes, no: no] DEFAULT yes (Should the p-values be adjusted for multiple comparisons)
-# PARAMETER p.value.adjustment.method: p.value.adjustment.method TYPE [none: none, bonferroni: bonferroni, holm: holm, hochberg: hochberg, BH: BH, BY: BY] DEFAULT BH (Multiple testing correction method)
-# PARAMETER interactions: interactions TYPE [main: "main effects", two-way: "main effects and interactions"] DEFAULT main (What to include in the model)
+# PARAMETER main.effect1: "Main effect 1" TYPE METACOLUMN_SEL DEFAULT group (Main effect 1)
+# PARAMETER main.effect2: "Main effect 2" TYPE METACOLUMN_SEL DEFAULT EMPTY (Main effect 2)
+# PARAMETER main.effect3: "Main effect 3" TYPE METACOLUMN_SEL DEFAULT EMPTY (Main effect 3)
+# PARAMETER technical.replication: "Technical replication" TYPE METACOLUMN_SEL DEFAULT EMPTY (Technical replication)
+# PARAMETER pairing: "Pairing" TYPE METACOLUMN_SEL DEFAULT EMPTY (Paired samples)
+# PARAMETER treat.main.effect1.as.factor: "Treat main effect 1 as factor" TYPE [no: no, yes: yes] DEFAULT no (Should main.effect1 be treated as a factor)
+# PARAMETER treat.main.effect2.as.factor: "Treat main effect 2 as factor" TYPE [no: no, yes: yes] DEFAULT no (Should main.effect2 be treated as a factor)
+# PARAMETER treat.main.effect3.as.factor: "Treat main effect 3 as factor" TYPE [no: no, yes: yes] DEFAULT no (Should main.effect3 be treated as a factor)
+# PARAMETER adjust.p.values: "Adjust p-values" TYPE [yes: yes, no: no] DEFAULT yes (Should the p-values be adjusted for multiple comparisons)
+# PARAMETER p.value.adjustment.method: "p-value adjustment method" TYPE [none: none, bonferroni: Bonferroni, holm: Holm, hochberg: Hochberg, BH: BH, BY: BY] DEFAULT BH (Multiple testing correction method)
+# PARAMETER interactions: "Interactions" TYPE [main: "main effects", two-way: "main effects and interactions"] DEFAULT main (What to include in the model)
 
 # PARAMETER significance [main, interactions] DEFAULT main (Which p-values to return)
 
 # JTT, 22.10.2007: Linear Modelling using limma
 # MG, 28.03.2012, modified to handle NUID:s
 # MK, 22.02.2014, modified so that does not report anymore coef or p-vals for pairing information
+# OH, 12.02.2015, getting columns from phenodata using which rather than grep in order to get exact matches
 
 #main.effect1<-"group"
 #main.effect2<-"gender"
@@ -45,7 +46,6 @@ file<-c("normalized.tsv")
 dat<-read.table(file, header=T, sep="\t", row.names=1)
 
 # Separates expression values and flags
-calls<-dat[,grep("flag", names(dat))]
 dat2<-dat[,grep("chip", names(dat))]
 
 # Loads phenodata
@@ -65,11 +65,11 @@ if((main.effect2=="EMPTY" & main.effect3=="EMPTY" & interactions=="two-way") | (
 #}
 
 # Extracting the variables from phenodata
-main1<-phenodata[,grep(main.effect1, colnames(phenodata))]
-main2<-phenodata[,grep(main.effect2, colnames(phenodata))]
-main3<-phenodata[,grep(main.effect3, colnames(phenodata))]
-techrep<-phenodata[,grep(technical.replication, colnames(phenodata))]
-pair<-phenodata[,grep(pairing, colnames(phenodata))]
+main1<-phenodata[,which(main.effect1==colnames(phenodata))]
+main2<-phenodata[,which(main.effect2==colnames(phenodata))]
+main3<-phenodata[,which(main.effect3==colnames(phenodata))]
+techrep<-phenodata[,which(technical.replication==colnames(phenodata))]
+pair<-phenodata[,which(pairing==colnames(phenodata))]
 
 # Converting vectors to factor, if needed
 if(treat.main.effect1.as.factor=="yes") {
