@@ -14,7 +14,7 @@ then
 fi
 
 # command for running java
-COMMAND="java -cp ../shared/lib/*: fi.csc.microarray.messaging.admin.CompAdmin"
+COMMAND="sudo -u chipster java -cp ../shared/lib/*: fi.csc.microarray.messaging.admin.CompAdmin"
 
 # run and hide help texts of config parameter, because it's already set by this script
 $COMMAND $CONF $@ | sed "s/--config=CHIPSTER-CONFIG.XML//g" | sed "s/Chipster manager config file//g"
